==> ws-v3.80.3-src.tar.gz: ws-v3.80-3/include/btron/WSDbtronFont.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDBTRONFONT_H
#define WSDBTRONFONT_H

#include <btron/font.h>
#include <WScom.h>
#include <WSDres.h>
#include <WSDfont.h>

class WSDbtronFont               :public WSDfont {

 protected:
  long _font_height;
  UW _fno;
  FSSPEC _fnt;
  FSSPEC _fnt2;


  virtual long initialize();
  virtual long destroy();

 public:
  WSDbtronFont();
  virtual ~WSDbtronFont();
  virtual long getStringWidth(WSCstring*);
  virtual long getStringHeight(WSCstring*);
  virtual long getStringWidthUCS2(WSCushort*);
  virtual long getStringHeightUCS2(WSCushort*);

//  long getXFontSet();

  WSMFclassDef(WSDbtronFont,WSDfont);
};
#endif //WSDBTRONFONT_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/btron/WSDbtronFont.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSDBTRONFONT_H
#define WSDBTRONFONT_H

#include <btron/font.h>
#ifdef _NOTSH
typedef struct ExtendFontSpecifier2{
  TC   name[12];
  UW   fclass;
  UW   attr;
  SIZE size;
  W    _f;
} FSSPEC2;
#endif
#include <WScom.h>
#include <WSDres.h>
#include <WSDfont.h>

class WSDbtronFont               :public WSDfont {

 protected:
  long _font_height;
  UW _fno;
#ifdef _NOTSH
  FSSPEC2 _fnt;
  FSSPEC2 _fnt2;
#else
  FSSPEC _fnt;
  FSSPEC _fnt2;
#endif
  W      _font_desc;

  virtual long initialize();
  virtual long destroy();

 public:
  WSDbtronFont();
  virtual ~WSDbtronFont();
  virtual long getStringWidth(WSCstring*);
  virtual long getStringHeight(WSCstring*);
  virtual long getStringWidthUCS2(WSCushort*);
  virtual long getStringHeightUCS2(WSCushort*);

  virtual long getAscent();
  virtual long getDescent();
  FSSPEC* getAsciiFontFSSPEC();
  FSSPEC* get2byteFontFSSPEC();
  
//  long getXFontSet();

  WSMFclassDef(WSDbtronFont,WSDfont);
};
#endif //WSDBTRONFONT_H
